==> kdevelop_4.7.0.orig.tar.xz: kdevelop-4.7.0/formatters/customscript/kdevcustomscript.desktop.cmake <==
[Desktop Entry]
Type=Service
Exec=blubb
Icon=kdevelop
Comment=A plugin for formatting C files using custom scripts
Comment[bs]=Dodatak za formatiranje C datoteka koristeći vlastite skripte
Comment[ca]=Un connector per formatar fitxers C usant scripts personalitzats
Comment[ca@valencia]=Un connector per formatar fitxers C usant scripts personalitzats
Comment[da]=Et plugin til formatering af C-filer som bruger brugerdefinerede scripts
Comment[de]=Ein Modul zum Formatieren von C-Dateien mit Hilfe von eigenen Skripten
Comment[el]=Ένα πρόσθετο διαμόρφωσης αρχείων C με χρήση προσαρμοσμένων σεναρίων
Comment[en_GB]=A plugin for formatting C files using custom scripts
Comment[es]=Un complemento para formatear archivos C usando scripts personalizados
Comment[et]=Plugin C-failide vormindamiseks kohandatud skriptidega
Comment[fi]=Liitännäinen C-tiedostojen muotoiluun käyttäen mukautettuja skriptejä
Comment[fr]=Un module externe pour le formatage de fichiers C utilisant des scripts personnalisés
Comment[ga]=Breiseán a fhormáidíonn cód foinseach C le scripteanna saincheaptha
Comment[gl]=Un engadido para formatar os ficheiros en C empregando scripts personalizados
Comment[hu]=Bővítmény a C fájlok formázásához egyéni parancsfájlokkal
Comment[it]=Un'estensione per la formattazione di file in C che usa script personalizzati
Comment[kk]=C файлдарын пайдаланушының скрипттерінін көмегімен пішімдеу плагині
Comment[nb]=Et programtillegg for formattering av C-filer ved bruk av egne skripter
Comment[nds]=En Moduul, dat C-Dateien mit egen Skripten formateert
Comment[nl]=Een plugin voor het formatteren van C-bestanden met eigen scripts
Comment[pl]=Wtyczka do formatowania plików C wykorzystująca własne skrypty
Comment[pt]=Um 'plugin' para formatar ficheiros em C com programas personalizados
Comment[pt_BR]=Um plugin para formatar arquivos em C usando scripts personalizados
Comment[ru]=Расширение для форматирования кода C с помощью настраиваемых сценариев
Comment[sk]=Modul pre formátovanie súborov C pomocou vlastných skriptov
Comment[sl]=Vstavek za oblikovanje izvorne kode C s pomočjo skript po meri
Comment[sv]=Ett insticksprogram för att formatera C-filer med egna skript
Comment[uk]=Додаток для форматування файлів мовою C за допомогою нетипових скриптів
Comment[x-test]=xxA plugin for formatting C files using custom scriptsxx
Comment[zh_CN]=使用自定义脚本格式化 C 文件的插件
Comment[zh_TW]=使用自訂文稿排列 C 語言程式碼的外掛程式
Name=Custom Script Formatter Backend
Name[bs]=Pozadinski program za formatiranje vlastitih skripti
Name[ca]=Dorsal de l'script formatador personalitzat
Name[ca@valencia]=Dorsal de l'script formatador personalitzat
Name[da]=Backend til formatering med brugerdefinerede scripts
Name[de]=Backend für einen Formatierer für eigene Skripte
Name[el]=Σύστημα υποστήριξης διαμορφωτή προσαρμοσμένου σεναρίου
Name[en_GB]=Custom Script Formatter Backend
Name[es]=Motor del formateador de scripts personalizados
Name[et]=Kohandatud skriptiga vormindaja taustaprogramm
Name[fi]=Mukautetun skriptin muotoilijataustaohjelma
Name[fr]=Moteur de formatage de scripts personnalisés
Name[gl]=Infraestrutura de formatación de scripts personalizados
Name[hu]=Egyéni parancsfájl-formázó háttérprogram
Name[it]=Backend formattatore script personalizzato
Name[kk]=Пайдаланушы скрипттер пішімдегіш тетігі
Name[nb]=Bakgrunnsmotor for formattering med egne skripter
Name[nds]=Egen Skript-Formateerhülpprogramm
Name[nl]=Eigen script voor formatteerbackend
Name[pl]=Silnik formatowania przy użyciu własnych skryptów
Name[pt]=Infra-Estrutura de Formatação Personalizada
Name[pt_BR]=Infraestrutura de formatação de scripts personalizados
Name[ru]=Механизм форматирования с применением сценариев
Name[sk]=Backend formátovača vlastného skriptu
Name[sl]=Zaledje oblikovalnika skript po meri
Name[sv]=Formateringsgränssnitt för eget skript
Name[uk]=Сервер скриптів нетипового форматування
Name[x-test]=xxCustom Script Formatter Backendxx
Name[zh_CN]=自定义脚本格式化器后端
Name[zh_TW]=自訂文稿格式器後端介面
GenericName=Formatter Backend
GenericName[bs]=Formater pozadine
GenericName[ca]=Dorsal del formatador
GenericName[ca@valencia]=Dorsal del formatador
GenericName[da]=Backend til formatering
GenericName[de]=Formatierer
GenericName[el]=Σύστημα υποστήριξης διαμορφωτή κειμένου
GenericName[en_GB]=Formatter Backend
GenericName[es]=Motor del formateador
GenericName[et]=Vormindamise taustaprogramm
GenericName[fi]=Muotoilijan taustaohjelma
GenericName[fr]=Moteur de formatage
GenericName[gl]=Infraestrutura de formato
GenericName[hu]=Formázó háttérprogram
GenericName[it]=Backend formattatore
GenericName[ja]=フォーマッタのバックエンド
GenericName[kk]=Пішімдегіш тетігі
GenericName[km]=កម្មវិធី​ខាង​ក្រោយ​របស់​កម្មវិធី​ធ្វើ​ទ្រង់ទ្រាយ
GenericName[nb]=Bakgrunnsmotor for formattering
GenericName[nds]=Formateerhülpprogramm
GenericName[nl]=Formatteer-backend
GenericName[pl]=Silnik formatowania
GenericName[pt]=Infra-Estrutura de Formatação
GenericName[pt_BR]=Formatador
GenericName[ru]=Механизм форматирования исходного кода
GenericName[sk]=Backend formátovača
GenericName[sl]=Zaledje oblikovalnika
GenericName[sv]=Formateringsgränssnitt
GenericName[tr]=Biçimleyici Arka Ucu
GenericName[ug]=پىچقۇچنىڭ ئارقا ئۇچى
GenericName[uk]=Сервер форматування
GenericName[x-test]=xxFormatter Backendxx
GenericName[zh_CN]=格式化器后端
GenericName[zh_TW]=格式器後端介面

ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevcustomscript
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDE-PluginInfo-Name=kdevcustomscript
X-KDE-PluginInfo-Author=David Nolden
X-KDE-PluginInfo-License=LGPL
X-KDE-PluginInfo-Category=Utilities
X-KDevelop-Category=Global
X-KDevelop-Interfaces=org.kdevelop.ISourceFormatter
X-KDevelop-Mode=NoGUI
X-KDevelop-LoadMode=AlwaysOn

==> kdevelop-4.7.1.tar.xz: kdevelop-4.7.1/formatters/customscript/kdevcustomscript.desktop.cmake <==
[Desktop Entry]
Type=Service
Exec=blubb
Icon=kdevelop
Comment=A plugin for formatting C files using custom scripts
Comment[bs]=Dodatak za formatiranje C datoteka koristeći vlastite skripte
Comment[ca]=Un connector per formatar fitxers C usant scripts personalitzats
Comment[ca@valencia]=Un connector per formatar fitxers C usant scripts personalitzats
Comment[da]=Et plugin til formatering af C-filer som bruger brugerdefinerede scripts
Comment[de]=Ein Modul zum Formatieren von C-Dateien mit Hilfe von eigenen Skripten
Comment[el]=Ένα πρόσθετο διαμόρφωσης αρχείων C με χρήση προσαρμοσμένων σεναρίων
Comment[en_GB]=A plugin for formatting C files using custom scripts
Comment[es]=Un complemento para formatear archivos C usando scripts personalizados
Comment[et]=Plugin C-failide vormindamiseks kohandatud skriptidega
Comment[fi]=Liitännäinen C-tiedostojen muotoiluun käyttäen mukautettuja skriptejä
Comment[fr]=Un module externe pour le formatage de fichiers C utilisant des scripts personnalisés
Comment[ga]=Breiseán a fhormáidíonn cód foinseach C le scripteanna saincheaptha
Comment[gl]=Un engadido para formatar os ficheiros en C empregando scripts personalizados
Comment[hu]=Bővítmény a C fájlok formázásához egyéni parancsfájlokkal
Comment[it]=Un'estensione per la formattazione di file in C che usa script personalizzati
Comment[kk]=C файлдарын пайдаланушының скрипттерінін көмегімен пішімдеу плагині
Comment[nb]=Et programtillegg for formattering av C-filer ved bruk av egne skripter
Comment[nds]=En Moduul, dat C-Dateien mit egen Skripten formateert
Comment[nl]=Een plugin voor het formatteren van C-bestanden met eigen scripts
Comment[pl]=Wtyczka do formatowania plików C wykorzystująca własne skrypty
Comment[pt]=Um 'plugin' para formatar ficheiros em C com programas personalizados
Comment[pt_BR]=Um plugin para formatar arquivos em C usando scripts personalizados
Comment[ru]=Расширение для форматирования кода C с помощью настраиваемых сценариев
Comment[sk]=Modul pre formátovanie súborov C pomocou vlastných skriptov
Comment[sl]=Vstavek za oblikovanje izvorne kode C s pomočjo skript po meri
Comment[sv]=Ett insticksprogram för att formatera C-filer med egna skript
Comment[tr]=Özel betikler kullanarak C dosyalarını biçimlendirmek için bir eklenti
Comment[uk]=Додаток для форматування файлів мовою C за допомогою нетипових скриптів
Comment[x-test]=xxA plugin for formatting C files using custom scriptsxx
Comment[zh_CN]=使用自定义脚本格式化 C 文件的插件
Comment[zh_TW]=使用自訂文稿排列 C 語言程式碼的外掛程式
Name=Custom Script Formatter Backend
Name[bs]=Pozadinski program za formatiranje vlastitih skripti
Name[ca]=Dorsal de l'script formatador personalitzat
Name[ca@valencia]=Dorsal de l'script formatador personalitzat
Name[da]=Backend til formatering med brugerdefinerede scripts
Name[de]=Backend für einen Formatierer für eigene Skripte
Name[el]=Σύστημα υποστήριξης διαμορφωτή προσαρμοσμένου σεναρίου
Name[en_GB]=Custom Script Formatter Backend
Name[es]=Motor del formateador de scripts personalizados
Name[et]=Kohandatud skriptiga vormindaja taustaprogramm
Name[fi]=Mukautetun skriptin muotoilijataustaohjelma
Name[fr]=Moteur de formatage de scripts personnalisés
Name[gl]=Infraestrutura de formatación de scripts personalizados
Name[hu]=Egyéni parancsfájl-formázó háttérprogram
Name[it]=Backend formattatore script personalizzato
Name[kk]=Пайдаланушы скрипттер пішімдегіш тетігі
Name[nb]=Bakgrunnsmotor for formattering med egne skripter
Name[nds]=Egen Skript-Formateerhülpprogramm
Name[nl]=Eigen script voor formatteerbackend
Name[pl]=Silnik formatowania przy użyciu własnych skryptów
Name[pt]=Infra-Estrutura de Formatação Personalizada
Name[pt_BR]=Infraestrutura de formatação de scripts personalizados
Name[ru]=Механизм форматирования с применением сценариев
Name[sk]=Backend formátovača vlastného skriptu
Name[sl]=Zaledje oblikovalnika skript po meri
Name[sv]=Formateringsgränssnitt för eget skript
Name[tr]=Özel Betik Biçimlendirici Arka Ucu
Name[uk]=Сервер скриптів нетипового форматування
Name[x-test]=xxCustom Script Formatter Backendxx
Name[zh_CN]=自定义脚本格式化器后端
Name[zh_TW]=自訂文稿格式器後端介面
GenericName=Formatter Backend
GenericName[bs]=Formater pozadine
GenericName[ca]=Dorsal del formatador
GenericName[ca@valencia]=Dorsal del formatador
GenericName[da]=Backend til formatering
GenericName[de]=Formatierer
GenericName[el]=Σύστημα υποστήριξης διαμορφωτή κειμένου
GenericName[en_GB]=Formatter Backend
GenericName[es]=Motor del formateador
GenericName[et]=Vormindamise taustaprogramm
GenericName[fi]=Muotoilijan taustaohjelma
GenericName[fr]=Moteur de formatage
GenericName[gl]=Infraestrutura de formato
GenericName[hu]=Formázó háttérprogram
GenericName[it]=Backend formattatore
GenericName[ja]=フォーマッタのバックエンド
GenericName[kk]=Пішімдегіш тетігі
GenericName[km]=កម្មវិធី​ខាង​ក្រោយ​របស់​កម្មវិធី​ធ្វើ​ទ្រង់ទ្រាយ
GenericName[nb]=Bakgrunnsmotor for formattering
GenericName[nds]=Formateerhülpprogramm
GenericName[nl]=Formatteer-backend
GenericName[pl]=Silnik formatowania
GenericName[pt]=Infra-Estrutura de Formatação
GenericName[pt_BR]=Formatador
GenericName[ru]=Механизм форматирования исходного кода
GenericName[sk]=Backend formátovača
GenericName[sl]=Zaledje oblikovalnika
GenericName[sv]=Formateringsgränssnitt
GenericName[tr]=Biçimleyici Arka Ucu
GenericName[ug]=پىچقۇچنىڭ ئارقا ئۇچى
GenericName[uk]=Сервер форматування
GenericName[x-test]=xxFormatter Backendxx
GenericName[zh_CN]=格式化器后端
GenericName[zh_TW]=格式器後端介面

ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevcustomscript
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDE-PluginInfo-Name=kdevcustomscript
X-KDE-PluginInfo-Author=David Nolden
X-KDE-PluginInfo-License=LGPL
X-KDE-PluginInfo-Category=Utilities
X-KDevelop-Category=Global
X-KDevelop-Interfaces=org.kdevelop.ISourceFormatter
X-KDevelop-Mode=NoGUI
X-KDevelop-LoadMode=AlwaysOn
